@@ -1,6 +1,8 @@
 from .draft_record import RDMDraftParentComponent
 from .ext_resource import RDMExtResourceModelComponent
+from .links import RDMLinksComponent
 from .marshmallow import RDMMarshmallowModelComponent
+from .pid import RDMPIDModelComponent
 from .record import RDMRecordModelComponent
 from .search_options import RDMSearchOptionsModelComponent
 from .service import RDMServiceComponent
@@ -14,4 +16,6 @@ RDM_COMPONENTS = [
     RDMMarshmallowModelComponent,
     RDMSearchOptionsModelComponent,
     RDMUIMarshmallowModelComponent,
+    RDMLinksComponent,
+    RDMPIDModelComponent,
 ]
